@@ -30,7 +30,7 @@ import sys
 import time
 import datetime
 import re
-import six
+from django.utils import six
 
 try:
     import decimal
@@ -191,7 +191,7 @@ def _configure_parameter(p, value):
 
     if isinstance(value, basestring):
         p.Value = value
-        p.Size = len(value)
+        #p.Size = len(value)
 
     elif isinstance(value, buffer):
         p.Size = len(value)
@@ -214,8 +214,28 @@ def _configure_parameter(p, value):
             p.NumericScale = 0
             p.Precision = digit_count + exponent
 
+    elif isinstance(value, datetime.datetime):
+        if getattr(settings, 'USE_TZ', False) and value.tzinfo:
+            value = value.astimezone(timezone.utc)
+        p.Type = adBSTR
+        s = value.isoformat(' ')
+        p.Value = s
+        p.Size = len(s)
+
     elif isinstance(value, datetime.time):
-            p.Value = datetime.datetime(1,1,1, value.hour, value.minute, value.second)
+        if getattr(settings, 'USE_TZ', False) and value.tzinfo:
+            value = value.astimezone(timezone.utc)
+        p.Type = adBSTR
+        s = value.isoformat()
+        p.Value = s
+        p.Size = len(s)
+
+    elif isinstance(value, datetime.date):
+        p.Type = adBSTR
+        s = value.isoformat()
+        p.Value = s
+        p.Size = len(s)
+
     else:
         # For any other type, set the value and let pythoncom do the right thing.
         p.Value = value
@@ -224,10 +244,6 @@ def _configure_parameter(p, value):
     if p.Size == 0:
         p.Size = -1
 
-VERSION_SQL2000 = 8
-VERSION_SQL2005 = 9
-VERSION_SQL2008 = 10
-
 class Connection(object):
     def __init__(self, adoConn, useTransactions=False):
         self.adoConn = adoConn
@@ -236,26 +252,19 @@ class Connection(object):
         self.adoConn.CursorLocation = defaultCursorLocation
         self.supportsTransactions = useTransactions
 
-        self.adoConnProperties = dict([(x.Name, x.Value) for x in self.adoConn.Properties])
-
         if self.supportsTransactions:
             self.adoConn.IsolationLevel = defaultIsolationLevel
             self.adoConn.BeginTrans() # Disables autocommit per DBPAI
 
-    @property
-    def is_sql2000(self):
-        v = self.adoConnProperties.get('DBMS Version', '')
-        return v.startswith(unicode(VERSION_SQL2000))
-
-    @property
-    def is_sql2005(self):
-        v = self.adoConnProperties.get('DBMS Version', '')
-        return v.startswith(unicode(VERSION_SQL2005))
-    
-    @property
-    def is_sql2008(self):
-        v = self.adoConnProperties.get('DBMS Version', '')
-        return v.startswith(unicode(VERSION_SQL2008))
+    def set_autocommit(self, value):
+        if self.supportsTransactions == (not value):
+            return
+        if self.supportsTransactions:
+            self.adoConn.RollbackTrans() # Disables autocommit per DBPAI
+        else:
+            self.adoConn.IsolationLevel = defaultIsolationLevel
+            self.adoConn.BeginTrans() # Disables autocommit per DBPAI
+        self.supportsTransactions = not value
 
     def _raiseConnectionError(self, errorclass, errorvalue):
         eh = self.errorhandler
@@ -302,8 +311,13 @@ class Connection(object):
     def rollback(self):
         """Abort a pending transaction."""
         self.messages = []
-        if not self.supportsTransactions:
-            self._raiseConnectionError(NotSupportedError, None)
+        #if not self.supportsTransactions:
+        #    self._raiseConnectionError(NotSupportedError, None)
+        with self.cursor() as cursor:
+            cursor.execute("select @@TRANCOUNT")
+            trancount, = cursor.fetchone()
+        if trancount == 0:
+            return
 
         self.adoConn.RollbackTrans()
         if not(self.adoConn.Attributes & adXactAbortRetaining):
@@ -452,8 +466,8 @@ class Cursor(object):
             self._description_from_recordset(recordset[0])
         except Exception as e:
             _message = ""
-            if hasattr(e, 'args'): _message += str(e.args)+"\n"
-            _message += "Command:\n%s\nParameters:\n%s" %  (self.cmd.CommandText, format_parameters(self.cmd.Parameters, True))
+            if hasattr(e, 'args'): _message += str(e.args)
+            #_message += "Command:\n%s\nParameters:\n%s" %  (self.cmd.CommandText, format_parameters(self.cmd.Parameters, True))
             klass = self.connection._suggest_error_class()
             self._raiseCursorError(klass, _message)
 
@@ -618,7 +632,7 @@ class Cursor(object):
         """
         self.messages = list()
         if self.connection is None or self.rs is None:
-            self._raiseCursorError(Error, None)
+            #self._raiseCursorError(Error, None)
             return None
 
         recordset = self.rs.NextRecordset()[0]
@@ -708,7 +722,7 @@ _variantConversions = MultiMap(
         (adBoolean,): bool,
         adoLongTypes+adoRowIdTypes : long,
         adoIntegerTypes: int,
-        adoBinaryTypes: buffer, 
+        adoBinaryTypes: buffer,
     }, 
     lambda x: x)
 
