@@ -258,9 +258,18 @@ class SqlServerBaseWrapper(BaseDatabaseWrapper):
                 if cursor.description:
                     raise utils.IntegrityError(cursor.fetchall())
 
+    def is_usable(self):
+        try:
+            # Use a cursor directly, bypassing Django's utilities.
+            self.connection.cursor().execute("SELECT 1")
+        except pytz.Error:
+            return False
+        else:
+            return True
+
     def _savepoint_commit(self, sid):
         pass
 
     def schema_editor(self):
         """Returns a new instance of this backend's SchemaEditor"""
-        return DatabaseSchemaEditor(self)
\ No newline at end of file
+        return DatabaseSchemaEditor(self)
