@@ -1,13 +1,14 @@
-# This dictionary maps Field objects to their associated Server Server column
-# types, as strings. Column-type strings can contain format strings; they'll
-# be interpolated against the values of Field.__dict__.
+from __future__ import absolute_import
+
 from django.conf import settings
 from django.db.backends.creation import BaseDatabaseCreation, TEST_DATABASE_PREFIX
 from django.db.utils import load_backend
-import sys
-import  six
+from django.utils import six
 
 class DatabaseCreation(BaseDatabaseCreation):
+    # This dictionary maps Field objects to their associated Server Server column
+    # types, as strings. Column-type strings can contain format strings; they'll
+    # be interpolated against the values of Field.__dict__.
     data_types = {
         'AutoField':                    'int IDENTITY (1, 1)',
         'BigAutoField':                 'bigint IDENTITY (1, 1)',
@@ -15,15 +16,22 @@ class DatabaseCreation(BaseDatabaseCreation):
         'BooleanField':                 'bit',
         'CharField':                    'nvarchar(%(max_length)s)',
         'CommaSeparatedIntegerField':   'nvarchar(%(max_length)s)',
-        'DateField':                    'datetime',
-        'DateTimeField':                'datetime',
+        'DateField':                    'date',
+        'DateTimeField':                'datetime2',
+        'DateTimeOffsetField':          'datetimeoffset',
         'DecimalField':                 'decimal(%(max_digits)s, %(decimal_places)s)',
         'FileField':                    'nvarchar(%(max_length)s)',
         'FilePathField':                'nvarchar(%(max_length)s)',
         'FloatField':                   'double precision',
+        'GenericIPAddressField':        'nvarchar(39)',
         'IntegerField':                 'int',
         'IPAddressField':               'nvarchar(15)',
-        'GenericIPAddressField':        'nvarchar(39)',
+        'LegacyDateField':              'datetime',
+        'LegacyDateTimeField':          'datetime',
+        'LegacyTimeField':              'time',
+        'NewDateField':                 'date',
+        'NewDateTimeField':             'datetime2',
+        'NewTimeField':                 'time',
         'NullBooleanField':             'bit',
         'OneToOneField':                'int',
         'PositiveIntegerField':         'int CHECK ([%(column)s] >= 0)',
@@ -31,16 +39,19 @@ class DatabaseCreation(BaseDatabaseCreation):
         'SlugField':                    'nvarchar(%(max_length)s)',
         'SmallIntegerField':            'smallint',
         'TextField':                    'nvarchar(max)',
-        'TimeField':                    'datetime',
+        'TimeField':                    'time',
+        'BinaryField':                  'varbinary(max)',
     }
-    _sql2008_date_types = {
-        'DateField': 'date',
-        'DateTimeField': 'datetime2(6)',
-        'TimeField': 'time(6)',
-        }
 
-    def _patch_for_sql2008_and_up(self):
-        self.data_types.update(self._sql2008_date_types)
+    def __init__(self, *args, **kwargs):
+        super(DatabaseCreation, self).__init__(*args, **kwargs)
+
+        if self.connection.use_legacy_date_fields:
+            self.data_types.update({
+                'DateField': 'datetime',
+                'DateTimeField': 'datetime',
+                'TimeField': 'datetime',
+            })
 
     def _create_master_connection(self):
         """
@@ -76,6 +87,11 @@ class DatabaseCreation(BaseDatabaseCreation):
         try:
             super(DatabaseCreation, self)._create_test_db(verbosity, autoclobber)
             self.install_regex(test_database_name)
+        except Exception as e:
+            if 'Choose a different database name.' in str(e):
+                six.print_('Database "%s" could not be created because it already exists.' % test_database_name)
+            else:
+                raise
         finally:
             # set thing back
             self.connection.close()
@@ -92,7 +108,7 @@ class DatabaseCreation(BaseDatabaseCreation):
         sql = 'CREATE ASSEMBLY regex_clr FROM 0x' + assembly
         cursor = self.connection.cursor()
         try:
-            cursor.execute('USE [{}]'.format(test_database_name))
+            cursor.execute('USE [{0}]'.format(test_database_name))
             cursor.execute(sql)
             cursor.execute('''
             create function REGEXP_LIKE
@@ -124,6 +140,11 @@ class DatabaseCreation(BaseDatabaseCreation):
 
         try:
             super(DatabaseCreation, self)._destroy_test_db(test_database_name, verbosity)
+        except Exception as e:
+            if 'it is currently in use' in str(e):
+                six.print_('Cannot drop database %s because it is in use' % test_database_name)
+            else:
+                raise
         finally:
             self.connection = old_wrapper
 
@@ -172,7 +193,7 @@ class DatabaseCreation(BaseDatabaseCreation):
                 fix_fields.append(f)
                 f._unique = False
         for field_constraints in opts.unique_together:
-            predicate_parts = ['[{}] '.format(opts.get_field(f).column) + style.SQL_KEYWORD('IS NOT NULL')
+            predicate_parts = ['[{0}] '.format(opts.get_field(f).column) + style.SQL_KEYWORD('IS NOT NULL')
                                for f in field_constraints if opts.get_field(f).null]
             index_name = 'UX_{table}_{columns}'.format(
                 table=opts.db_table,
