@@ -99,10 +99,10 @@ class DatabaseOperations(BaseDatabaseOperations):
         seconds = ((timedelta.days * 86400) + timedelta.seconds) * sign
         out = sql
         if seconds:
-            out = u'DATEADD(SECOND, {0}, CAST({1} as datetime))'.format(seconds, sql)
+            out = 'DATEADD(SECOND, {0}, CAST({1} as datetime))'.format(seconds, sql)
         if timedelta.microseconds:
             # DATEADD with datetime doesn't support ms, must cast up
-            out = u'DATEADD(MICROSECOND, {ms}, CAST({sql} as datetime2))'.format(
+            out = 'DATEADD(MICROSECOND, {ms}, CAST({sql} as datetime2))'.format(
                 ms=timedelta.microseconds * sign,
                 sql=out,
             )
